@@ -37,6 +37,7 @@ class Namespace(CdkResource):
     create_take_over_script: Optional[ScriptSetting] = None
     do_take_over_script: Optional[ScriptSetting] = None
     ban_script: Optional[ScriptSetting] = None
+    un_ban_script: Optional[ScriptSetting] = None
     log_setting: Optional[LogSetting] = None
 
     def __init__(
@@ -59,6 +60,7 @@ class Namespace(CdkResource):
         self.create_take_over_script = options.create_take_over_script if options.create_take_over_script else None
         self.do_take_over_script = options.do_take_over_script if options.do_take_over_script else None
         self.ban_script = options.ban_script if options.ban_script else None
+        self.un_ban_script = options.un_ban_script if options.un_ban_script else None
         self.log_setting = options.log_setting if options.log_setting else None
         stack.add_resource(
             self,
@@ -103,6 +105,9 @@ class Namespace(CdkResource):
         if self.ban_script is not None:
             properties["BanScript"] = self.ban_script.properties(
             )
+        if self.un_ban_script is not None:
+            properties["UnBanScript"] = self.un_ban_script.properties(
+            )
         if self.log_setting is not None:
             properties["LogSetting"] = self.log_setting.properties(
             )
