@@ -17,6 +17,8 @@ from .TakeOverTypeModel import TakeOverTypeModel
 from .options.TakeOverTypeModelOptions import TakeOverTypeModelOptions
 from .OpenIdConnectSetting import OpenIdConnectSetting
 from .options.OpenIdConnectSettingOptions import OpenIdConnectSettingOptions
+from .ScopeValue import ScopeValue
+from .options.ScopeValueOptions import ScopeValueOptions
 from .PlatformUser import PlatformUser
 from .options.PlatformUserOptions import PlatformUserOptions
 from .BanStatus import BanStatus
