@@ -23,4 +23,12 @@ from .Material import Material
 from .options.MaterialOptions import MaterialOptions
 from .UnleashRateEntryModel import UnleashRateEntryModel
 from .options.UnleashRateEntryModelOptions import UnleashRateEntryModelOptions
+from .VerifyActionResult import VerifyActionResult
+from .options.VerifyActionResultOptions import VerifyActionResultOptions
+from .ConsumeActionResult import ConsumeActionResult
+from .options.ConsumeActionResultOptions import ConsumeActionResultOptions
+from .AcquireActionResult import AcquireActionResult
+from .options.AcquireActionResultOptions import AcquireActionResultOptions
+from .TransactionResult import TransactionResult
+from .options.TransactionResultOptions import TransactionResultOptions
 from .CurrentMasterData import CurrentMasterData
\ No newline at end of file
