@@ -24,17 +24,17 @@ from .options.BlockingPolicyModelReputationIpDetectionIsEnableOptions import Blo
 from .options.BlockingPolicyModelReputationIpDetectionIsDisableOptions import BlockingPolicyModelReputationIpDetectionIsDisableOptions
 from .options.BlockingPolicyModelIpAddressesDetectionIsEnableOptions import BlockingPolicyModelIpAddressesDetectionIsEnableOptions
 from .options.BlockingPolicyModelIpAddressesDetectionIsDisableOptions import BlockingPolicyModelIpAddressesDetectionIsDisableOptions
-from .enum.BlockingPolicyModelDefaultRestriction import BlockingPolicyModelDefaultRestriction
-from .enum.BlockingPolicyModelLocationDetection import BlockingPolicyModelLocationDetection
-from .enum.BlockingPolicyModelLocationRestriction import BlockingPolicyModelLocationRestriction
-from .enum.BlockingPolicyModelAnonymousIpDetection import BlockingPolicyModelAnonymousIpDetection
-from .enum.BlockingPolicyModelAnonymousIpRestriction import BlockingPolicyModelAnonymousIpRestriction
-from .enum.BlockingPolicyModelHostingProviderIpDetection import BlockingPolicyModelHostingProviderIpDetection
-from .enum.BlockingPolicyModelHostingProviderIpRestriction import BlockingPolicyModelHostingProviderIpRestriction
-from .enum.BlockingPolicyModelReputationIpDetection import BlockingPolicyModelReputationIpDetection
-from .enum.BlockingPolicyModelReputationIpRestriction import BlockingPolicyModelReputationIpRestriction
-from .enum.BlockingPolicyModelIpAddressesDetection import BlockingPolicyModelIpAddressesDetection
-from .enum.BlockingPolicyModelIpAddressRestriction import BlockingPolicyModelIpAddressRestriction
+from .enums.BlockingPolicyModelDefaultRestriction import BlockingPolicyModelDefaultRestriction
+from .enums.BlockingPolicyModelLocationDetection import BlockingPolicyModelLocationDetection
+from .enums.BlockingPolicyModelLocationRestriction import BlockingPolicyModelLocationRestriction
+from .enums.BlockingPolicyModelAnonymousIpDetection import BlockingPolicyModelAnonymousIpDetection
+from .enums.BlockingPolicyModelAnonymousIpRestriction import BlockingPolicyModelAnonymousIpRestriction
+from .enums.BlockingPolicyModelHostingProviderIpDetection import BlockingPolicyModelHostingProviderIpDetection
+from .enums.BlockingPolicyModelHostingProviderIpRestriction import BlockingPolicyModelHostingProviderIpRestriction
+from .enums.BlockingPolicyModelReputationIpDetection import BlockingPolicyModelReputationIpDetection
+from .enums.BlockingPolicyModelReputationIpRestriction import BlockingPolicyModelReputationIpRestriction
+from .enums.BlockingPolicyModelIpAddressesDetection import BlockingPolicyModelIpAddressesDetection
+from .enums.BlockingPolicyModelIpAddressRestriction import BlockingPolicyModelIpAddressRestriction
 
 
 class BlockingPolicyModel:
