@@ -11,15 +11,20 @@
 # on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 # express or implied. See the License for the specific language governing
 # permissions and limitations under the License.
+#
+# deny overwrite
+
 from __future__ import annotations
 from typing import *
 
+from .AttachGuard import AttachGuard
 from ...core.model import CdkResource, Stack
 from ...core.func import GetAttr
 
 from ..ref.IdentifierRef import IdentifierRef
 
 from .options.IdentifierOptions import IdentifierOptions
+from ...guard import Namespace
 
 
 class Identifier(CdkResource):
@@ -72,6 +77,44 @@ class Identifier(CdkResource):
             client_id,
         )
 
+    def attach(
+        self,
+        guard_namespace: Namespace,
+    ) -> Identifier:
+        AttachGuard(
+            self.stack,
+            self.user_name,
+            self.get_attr_client_id(
+            ).str(
+            ),
+            guard_namespace.get_attr_namespace_id(
+            ).str(
+            ),
+        ).add_depends_on(
+            self,
+        ).add_depends_on(
+            guard_namespace,
+        )
+
+        return self
+
+    def attach_grn(
+        self,
+        guard_namespace_grn: str,
+    ) -> Identifier:
+        AttachGuard(
+            self.stack,
+            self.user_name,
+            self.get_attr_client_id(
+            ).str(
+            ),
+            guard_namespace_grn,
+        ).add_depends_on(
+            self,
+        )
+
+        return self
+
     def get_attr_client_id(
         self,
     ) -> GetAttr:
