@@ -22,9 +22,9 @@ from .options.BonusModelModeIsScheduleOptions import BonusModelModeIsScheduleOpt
 from .options.BonusModelModeIsStreamingOptions import BonusModelModeIsStreamingOptions
 from .options.BonusModelMissedReceiveReliefIsEnabledOptions import BonusModelMissedReceiveReliefIsEnabledOptions
 from .options.BonusModelMissedReceiveReliefIsDisabledOptions import BonusModelMissedReceiveReliefIsDisabledOptions
-from .enum.BonusModelMode import BonusModelMode
-from .enum.BonusModelRepeat import BonusModelRepeat
-from .enum.BonusModelMissedReceiveRelief import BonusModelMissedReceiveRelief
+from .enums.BonusModelMode import BonusModelMode
+from .enums.BonusModelRepeat import BonusModelRepeat
+from .enums.BonusModelMissedReceiveRelief import BonusModelMissedReceiveRelief
 
 
 class BonusModel:
