@@ -15,15 +15,15 @@ from .Namespace import Namespace
 from .options.NamespaceOptions import NamespaceOptions
 from .LotteryModel import LotteryModel
 from .options.LotteryModelOptions import LotteryModelOptions
-from .enum.LotteryModelMode import LotteryModelMode
-from .enum.LotteryModelMethod import LotteryModelMethod
+from .enums.LotteryModelMode import LotteryModelMode
+from .enums.LotteryModelMethod import LotteryModelMethod
 from .options.LotteryModelMethodIsPrizeTableOptions import LotteryModelMethodIsPrizeTableOptions
 from .options.LotteryModelMethodIsScriptOptions import LotteryModelMethodIsScriptOptions
 from .PrizeTable import PrizeTable
 from .options.PrizeTableOptions import PrizeTableOptions
 from .Prize import Prize
 from .options.PrizeOptions import PrizeOptions
-from .enum.PrizeType import PrizeType
+from .enums.PrizeType import PrizeType
 from .options.PrizeTypeIsActionOptions import PrizeTypeIsActionOptions
 from .options.PrizeTypeIsPrizeTableOptions import PrizeTypeIsPrizeTableOptions
 from .PrizeLimit import PrizeLimit
