@@ -24,6 +24,7 @@ from ..model.ScopedValue import ScopedValue
 from ..stamp_sheet.ReceiveByUserId import ReceiveByUserId
 from ..stamp_sheet.BatchReceiveByUserId import BatchReceiveByUserId
 from ..stamp_sheet.DecreaseCounterByUserId import DecreaseCounterByUserId
+from ..stamp_sheet.ResetCounterByUserId import ResetCounterByUserId
 from ..stamp_sheet.VerifyCompleteByUserId import VerifyCompleteByUserId
 from ..stamp_sheet.VerifyCounterValueByUserId import VerifyCounterValueByUserId
 
@@ -133,6 +134,19 @@ class NamespaceRef:
             user_id,
         )
 
+    def reset_counter(
+        self,
+        counter_name: str,
+        scopes: List[ScopedValue],
+        user_id: Optional[str] = "#{userId}",
+    ) -> ResetCounterByUserId:
+        return ResetCounterByUserId(
+            self.namespace_name,
+            counter_name,
+            scopes,
+            user_id,
+        )
+
     def verify_complete(
         self,
         mission_group_name: str,
