@@ -18,10 +18,15 @@ from .SubscribeTransaction import SubscribeTransaction
 from .options.SubscribeTransactionOptions import SubscribeTransactionOptions
 from .enums.SubscribeTransactionStore import SubscribeTransactionStore
 from .enums.SubscribeTransactionStatusDetail import SubscribeTransactionStatusDetail
+from .RefundHistory import RefundHistory
+from .options.RefundHistoryOptions import RefundHistoryOptions
 from .StoreContentModel import StoreContentModel
 from .options.StoreContentModelOptions import StoreContentModelOptions
 from .StoreSubscriptionContentModel import StoreSubscriptionContentModel
 from .options.StoreSubscriptionContentModelOptions import StoreSubscriptionContentModelOptions
+from .enums.StoreSubscriptionContentModelTriggerExtendMode import StoreSubscriptionContentModelTriggerExtendMode
+from .options.StoreSubscriptionContentModelTriggerExtendModeIsJustOptions import StoreSubscriptionContentModelTriggerExtendModeIsJustOptions
+from .options.StoreSubscriptionContentModelTriggerExtendModeIsRollupHourOptions import StoreSubscriptionContentModelTriggerExtendModeIsRollupHourOptions
 from .Receipt import Receipt
 from .options.ReceiptOptions import ReceiptOptions
 from .enums.ReceiptStore import ReceiptStore
