@@ -16,6 +16,8 @@ from typing import *
 
 from ...core.func import GetAttr, Join
 from .ScriptRef import ScriptRef
+from ..stamp_sheet.InvokeScript import InvokeScript
+from ..model.RandomStatus import RandomStatus
 
 
 class NamespaceRef:
@@ -27,6 +29,20 @@ class NamespaceRef:
     ):
         self.namespace_name = namespace_name
 
+    def invoke_script(
+        self,
+        script_id: str,
+        args: Optional[str] = None,
+        random_status: Optional[RandomStatus] = None,
+        user_id: Optional[str] = "#{userId}",
+    ) -> InvokeScript:
+        return InvokeScript(
+            script_id,
+            args,
+            random_status,
+            user_id,
+        )
+
     def grn(
         self,
     ) -> str:
