@@ -17,4 +17,9 @@ from .SetMaxValueByUserId import SetMaxValueByUserId
 from .SetRecoverIntervalByUserId import SetRecoverIntervalByUserId
 from .SetRecoverValueByUserId import SetRecoverValueByUserId
 from .DecreaseMaxValueByUserId import DecreaseMaxValueByUserId
-from .ConsumeStaminaByUserId import ConsumeStaminaByUserId
\ No newline at end of file
+from .ConsumeStaminaByUserId import ConsumeStaminaByUserId
+from .VerifyStaminaValueByUserId import VerifyStaminaValueByUserId
+from .VerifyStaminaMaxValueByUserId import VerifyStaminaMaxValueByUserId
+from .VerifyStaminaRecoverIntervalMinutesByUserId import VerifyStaminaRecoverIntervalMinutesByUserId
+from .VerifyStaminaRecoverValueByUserId import VerifyStaminaRecoverValueByUserId
+from .VerifyStaminaOverflowValueByUserId import VerifyStaminaOverflowValueByUserId
\ No newline at end of file
